==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkUnstructuredGridVolumeZSweepMapper.java <==
// java wrapper for vtkUnstructuredGridVolumeZSweepMapper object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGridVolumeZSweepMapper extends vtkUnstructuredGridVolumeMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetImageSampleDistance_2(double id0);
  public void SetImageSampleDistance(double id0)
    { SetImageSampleDistance_2(id0); }

  private native double GetImageSampleDistanceMinValue_3();
  public double GetImageSampleDistanceMinValue()
    { return GetImageSampleDistanceMinValue_3(); }

  private native double GetImageSampleDistanceMaxValue_4();
  public double GetImageSampleDistanceMaxValue()
    { return GetImageSampleDistanceMaxValue_4(); }

  private native double GetImageSampleDistance_5();
  public double GetImageSampleDistance()
    { return GetImageSampleDistance_5(); }

  private native void SetMinimumImageSampleDistance_6(double id0);
  public void SetMinimumImageSampleDistance(double id0)
    { SetMinimumImageSampleDistance_6(id0); }

  private native double GetMinimumImageSampleDistanceMinValue_7();
  public double GetMinimumImageSampleDistanceMinValue()
    { return GetMinimumImageSampleDistanceMinValue_7(); }

  private native double GetMinimumImageSampleDistanceMaxValue_8();
  public double GetMinimumImageSampleDistanceMaxValue()
    { return GetMinimumImageSampleDistanceMaxValue_8(); }

  private native double GetMinimumImageSampleDistance_9();
  public double GetMinimumImageSampleDistance()
    { return GetMinimumImageSampleDistance_9(); }

  private native void SetMaximumImageSampleDistance_10(double id0);
  public void SetMaximumImageSampleDistance(double id0)
    { SetMaximumImageSampleDistance_10(id0); }

  private native double GetMaximumImageSampleDistanceMinValue_11();
  public double GetMaximumImageSampleDistanceMinValue()
    { return GetMaximumImageSampleDistanceMinValue_11(); }

  private native double GetMaximumImageSampleDistanceMaxValue_12();
  public double GetMaximumImageSampleDistanceMaxValue()
    { return GetMaximumImageSampleDistanceMaxValue_12(); }

  private native double GetMaximumImageSampleDistance_13();
  public double GetMaximumImageSampleDistance()
    { return GetMaximumImageSampleDistance_13(); }

  private native void SetAutoAdjustSampleDistances_14(int id0);
  public void SetAutoAdjustSampleDistances(int id0)
    { SetAutoAdjustSampleDistances_14(id0); }

  private native int GetAutoAdjustSampleDistancesMinValue_15();
  public int GetAutoAdjustSampleDistancesMinValue()
    { return GetAutoAdjustSampleDistancesMinValue_15(); }

  private native int GetAutoAdjustSampleDistancesMaxValue_16();
  public int GetAutoAdjustSampleDistancesMaxValue()
    { return GetAutoAdjustSampleDistancesMaxValue_16(); }

  private native int GetAutoAdjustSampleDistances_17();
  public int GetAutoAdjustSampleDistances()
    { return GetAutoAdjustSampleDistances_17(); }

  private native void AutoAdjustSampleDistancesOn_18();
  public void AutoAdjustSampleDistancesOn()
    { AutoAdjustSampleDistancesOn_18(); }

  private native void AutoAdjustSampleDistancesOff_19();
  public void AutoAdjustSampleDistancesOff()
    { AutoAdjustSampleDistancesOff_19(); }

  private native void SetIntermixIntersectingGeometry_20(int id0);
  public void SetIntermixIntersectingGeometry(int id0)
    { SetIntermixIntersectingGeometry_20(id0); }

  private native int GetIntermixIntersectingGeometryMinValue_21();
  public int GetIntermixIntersectingGeometryMinValue()
    { return GetIntermixIntersectingGeometryMinValue_21(); }

  private native int GetIntermixIntersectingGeometryMaxValue_22();
  public int GetIntermixIntersectingGeometryMaxValue()
    { return GetIntermixIntersectingGeometryMaxValue_22(); }

  private native int GetIntermixIntersectingGeometry_23();
  public int GetIntermixIntersectingGeometry()
    { return GetIntermixIntersectingGeometry_23(); }

  private native void IntermixIntersectingGeometryOn_24();
  public void IntermixIntersectingGeometryOn()
    { IntermixIntersectingGeometryOn_24(); }

  private native void IntermixIntersectingGeometryOff_25();
  public void IntermixIntersectingGeometryOff()
    { IntermixIntersectingGeometryOff_25(); }

  private native int GetMaxPixelListSize_26();
  public int GetMaxPixelListSize()
    { return GetMaxPixelListSize_26(); }

  private native void SetMaxPixelListSize_27(int id0);
  public void SetMaxPixelListSize(int id0)
    { SetMaxPixelListSize_27(id0); }

  private native void SetRayIntegrator_28(vtkUnstructuredGridVolumeRayIntegrator id0);
  public void SetRayIntegrator(vtkUnstructuredGridVolumeRayIntegrator id0)
    { SetRayIntegrator_28(id0); }

  private native long GetRayIntegrator_29();
  public vtkUnstructuredGridVolumeRayIntegrator GetRayIntegrator() {
    long temp = GetRayIntegrator_29();

    if (temp == 0) return null;
    return (vtkUnstructuredGridVolumeRayIntegrator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void Render_30(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_30(id0,id1); }

  private native int[]  GetImageInUseSize_31();
  public int[]  GetImageInUseSize()
    { return GetImageInUseSize_31(); }

  private native int[]  GetImageOrigin_32();
  public int[]  GetImageOrigin()
    { return GetImageOrigin_32(); }

  private native int[]  GetImageViewportSize_33();
  public int[]  GetImageViewportSize()
    { return GetImageViewportSize_33(); }

  public vtkUnstructuredGridVolumeZSweepMapper() { super(); }

  public vtkUnstructuredGridVolumeZSweepMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-armv6h.pkg.tar.xz: vtk/vtkUnstructuredGridVolumeZSweepMapper.java <==
// java wrapper for vtkUnstructuredGridVolumeZSweepMapper object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGridVolumeZSweepMapper extends vtkUnstructuredGridVolumeMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetImageSampleDistance_2(double id0);
  public void SetImageSampleDistance(double id0)
    { SetImageSampleDistance_2(id0); }

  private native double GetImageSampleDistanceMinValue_3();
  public double GetImageSampleDistanceMinValue()
    { return GetImageSampleDistanceMinValue_3(); }

  private native double GetImageSampleDistanceMaxValue_4();
  public double GetImageSampleDistanceMaxValue()
    { return GetImageSampleDistanceMaxValue_4(); }

  private native double GetImageSampleDistance_5();
  public double GetImageSampleDistance()
    { return GetImageSampleDistance_5(); }

  private native void SetMinimumImageSampleDistance_6(double id0);
  public void SetMinimumImageSampleDistance(double id0)
    { SetMinimumImageSampleDistance_6(id0); }

  private native double GetMinimumImageSampleDistanceMinValue_7();
  public double GetMinimumImageSampleDistanceMinValue()
    { return GetMinimumImageSampleDistanceMinValue_7(); }

  private native double GetMinimumImageSampleDistanceMaxValue_8();
  public double GetMinimumImageSampleDistanceMaxValue()
    { return GetMinimumImageSampleDistanceMaxValue_8(); }

  private native double GetMinimumImageSampleDistance_9();
  public double GetMinimumImageSampleDistance()
    { return GetMinimumImageSampleDistance_9(); }

  private native void SetMaximumImageSampleDistance_10(double id0);
  public void SetMaximumImageSampleDistance(double id0)
    { SetMaximumImageSampleDistance_10(id0); }

  private native double GetMaximumImageSampleDistanceMinValue_11();
  public double GetMaximumImageSampleDistanceMinValue()
    { return GetMaximumImageSampleDistanceMinValue_11(); }

  private native double GetMaximumImageSampleDistanceMaxValue_12();
  public double GetMaximumImageSampleDistanceMaxValue()
    { return GetMaximumImageSampleDistanceMaxValue_12(); }

  private native double GetMaximumImageSampleDistance_13();
  public double GetMaximumImageSampleDistance()
    { return GetMaximumImageSampleDistance_13(); }

  private native void SetAutoAdjustSampleDistances_14(int id0);
  public void SetAutoAdjustSampleDistances(int id0)
    { SetAutoAdjustSampleDistances_14(id0); }

  private native int GetAutoAdjustSampleDistancesMinValue_15();
  public int GetAutoAdjustSampleDistancesMinValue()
    { return GetAutoAdjustSampleDistancesMinValue_15(); }

  private native int GetAutoAdjustSampleDistancesMaxValue_16();
  public int GetAutoAdjustSampleDistancesMaxValue()
    { return GetAutoAdjustSampleDistancesMaxValue_16(); }

  private native int GetAutoAdjustSampleDistances_17();
  public int GetAutoAdjustSampleDistances()
    { return GetAutoAdjustSampleDistances_17(); }

  private native void AutoAdjustSampleDistancesOn_18();
  public void AutoAdjustSampleDistancesOn()
    { AutoAdjustSampleDistancesOn_18(); }

  private native void AutoAdjustSampleDistancesOff_19();
  public void AutoAdjustSampleDistancesOff()
    { AutoAdjustSampleDistancesOff_19(); }

  private native void SetIntermixIntersectingGeometry_20(int id0);
  public void SetIntermixIntersectingGeometry(int id0)
    { SetIntermixIntersectingGeometry_20(id0); }

  private native int GetIntermixIntersectingGeometryMinValue_21();
  public int GetIntermixIntersectingGeometryMinValue()
    { return GetIntermixIntersectingGeometryMinValue_21(); }

  private native int GetIntermixIntersectingGeometryMaxValue_22();
  public int GetIntermixIntersectingGeometryMaxValue()
    { return GetIntermixIntersectingGeometryMaxValue_22(); }

  private native int GetIntermixIntersectingGeometry_23();
  public int GetIntermixIntersectingGeometry()
    { return GetIntermixIntersectingGeometry_23(); }

  private native void IntermixIntersectingGeometryOn_24();
  public void IntermixIntersectingGeometryOn()
    { IntermixIntersectingGeometryOn_24(); }

  private native void IntermixIntersectingGeometryOff_25();
  public void IntermixIntersectingGeometryOff()
    { IntermixIntersectingGeometryOff_25(); }

  private native int GetMaxPixelListSize_26();
  public int GetMaxPixelListSize()
    { return GetMaxPixelListSize_26(); }

  private native void SetMaxPixelListSize_27(int id0);
  public void SetMaxPixelListSize(int id0)
    { SetMaxPixelListSize_27(id0); }

  private native void SetRayIntegrator_28(vtkUnstructuredGridVolumeRayIntegrator id0);
  public void SetRayIntegrator(vtkUnstructuredGridVolumeRayIntegrator id0)
    { SetRayIntegrator_28(id0); }

  private native long GetRayIntegrator_29();
  public vtkUnstructuredGridVolumeRayIntegrator GetRayIntegrator() {
    long temp = GetRayIntegrator_29();

    if (temp == 0) return null;
    return (vtkUnstructuredGridVolumeRayIntegrator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Render_30(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_30(id0,id1); }

  private native int[]  GetImageInUseSize_31();
  public int[]  GetImageInUseSize()
    { return GetImageInUseSize_31(); }

  private native int[]  GetImageOrigin_32();
  public int[]  GetImageOrigin()
    { return GetImageOrigin_32(); }

  private native int[]  GetImageViewportSize_33();
  public int[]  GetImageViewportSize()
    { return GetImageViewportSize_33(); }

  public vtkUnstructuredGridVolumeZSweepMapper() { super(); }

  public vtkUnstructuredGridVolumeZSweepMapper(long id) { super(id); }
  public native long   VTKInit();

}
